==> explainability-core-1.8.0.Final-sources.jar: org/kie/kogito/explainability/model/domain/NumericalFeatureDomain.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.model.domain;

import java.util.Set;

public class NumericalFeatureDomain implements FeatureDomain {

    private final double lowerBound;
    private final double upperBound;

    private NumericalFeatureDomain(double lowerBound, double upperBound) {
        this.lowerBound = lowerBound;
        this.upperBound = upperBound;
    }

    /**
     * Create a {@link FeatureDomain} for a continuous feature
     *
     * @param lowerBound The start point of the search space
     * @param upperBound The end point of the search space
     * @return A {@link FeatureDomain}
     */
    public static FeatureDomain create(double lowerBound, double upperBound) {
        return new NumericalFeatureDomain(lowerBound, upperBound);
    }

    @Override
    public boolean isEmpty() {
        return false;
    }

    @Override
    public Double getLowerBound() {
        return this.lowerBound;
    }

    @Override
    public Double getUpperBound() {
        return this.upperBound;
    }

    @Override
    public Set<String> getCategories() {
        return null;
    }
}

==> explainability-core-1.19.0.Final-sources.jar: org/kie/kogito/explainability/model/domain/NumericalFeatureDomain.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.model.domain;

import java.util.Set;

public class NumericalFeatureDomain implements FeatureDomain {

    protected final double lowerBound;
    protected final double upperBound;

    protected NumericalFeatureDomain(double lowerBound, double upperBound) {
        this.lowerBound = lowerBound;
        this.upperBound = upperBound;
    }

    /**
     * Create a {@link FeatureDomain} for a continuous feature
     *
     * @param lowerBound The start point of the search space
     * @param upperBound The end point of the search space
     * @return A {@link FeatureDomain}
     */
    public static FeatureDomain create(double lowerBound, double upperBound) {
        return new NumericalFeatureDomain(lowerBound, upperBound);
    }

    @Override
    public boolean isEmpty() {
        return false;
    }

    @Override
    public Double getLowerBound() {
        return this.lowerBound;
    }

    @Override
    public Double getUpperBound() {
        return this.upperBound;
    }

    @Override
    public Set<?> getCategories() {
        return null;
    }
}
